// This code checks the following claim made in the proof of Proposition
// 4.1 of the paper Explicit Kummer varieties of hyperelliptic Jacobian
// threefolds:
// The 36x64-matrix (s_i(T_j)) has generic rank 35.
// The code here can be used to compute the rank for any given septic 
// hyperellptic curve, but it is not feasible when the coefficients are
// treated as indeterminates.
//
// -- Steffen Mueller --



Attach("KummerThreefold.m");
import "KummerThreefold.m" : kappa;
F<f7, e1, e2, e3, e4, e5, e6, e7> := FunctionField(Rationals(), 8);

_<x> := PolynomialRing(F);
f := f7 * (x-e1) * (x-e2) * (x-e3) * (x-e4) * (x-e5) * (x-e6) * (x-e7);
C := HyperellipticCurve(f);
J := Jacobian(C);
T, phi := TwoTorsionSubgroup(J);
gens := OrderedGenerators(T);
// points contains the 2-torsion points
points := [];
for i1 in [0..1] do
  for i2 in [0..1] do
    for i3 in [0..1] do
      for i4 in [0..1] do
        for i5 in [0..1] do
          for i6 in [0..1] do
              Include(~points, i1*phi(gens[1]) + i2*phi(gens[2]) + 
                  i3*phi(gens[3]) + i4*phi(gens[4]) + i5*phi(gens[5]) 
                  + i6*phi(gens[6]));
          end for;
        end for;
      end for;
    end for;
  end for;
end for;

// The list coords contains Kummer coordinates of the two-torsion points
coords := [kappa(pt) : pt in points];                                  
st := [];
// The list st contains all s_i(T_j).
for i := 1 to 64 do
    s := [];
    for j := 1 to 8 do 
        for k := j to 8 do 
            Append(~s, coords[i, j] * coords[i, k]);
        end for;
    end for;
    Append(~st, s);
end for;
M := Matrix(F, st);
// Compute the rank for an example.
Rank(ChangeRing(Evaluate(M, [1,0,1,2,3,4,5,6 ]), Rationals())); // should be 35
